@@ -28,7 +28,7 @@ class ATTICA_EXPORT BaseJob : public QObject
     Q_OBJECT
 
 public:
-    virtual ~BaseJob();
+    ~BaseJob() override;
 
     Metadata metadata() const;
 
@@ -37,6 +37,13 @@ public:
         PasswordAttribute,
     };
 
+    /**
+     * @returns whether abort() has been called on the job
+     *
+     * @since 5.87
+     */
+    bool isAborted() const;
+
 public Q_SLOTS:
     void start();
     void abort();
